# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.36
#
# Don't modify this file, modify the SWIG interface instead.

package Math::GSL::Mode;
use base qw(Exporter);
use base qw(DynaLoader);
package Math::GSL::Modec;
bootstrap Math::GSL::Mode;
package Math::GSL::Mode;
@EXPORT = qw();

# ---------- BASE METHODS -------------

package Math::GSL::Mode;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package Math::GSL::Mode;


# ------- VARIABLE STUBS --------

package Math::GSL::Mode;

*GSL_PREC_DOUBLE = *Math::GSL::Modec::GSL_PREC_DOUBLE;
*GSL_PREC_SINGLE = *Math::GSL::Modec::GSL_PREC_SINGLE;
*GSL_PREC_APPROX = *Math::GSL::Modec::GSL_PREC_APPROX;
*GSL_MODE_DEFAULT = *Math::GSL::Modec::GSL_MODE_DEFAULT;
1;
