# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.36
#
# Don't modify this file, modify the SWIG interface instead.

package Math::GSL::Statistics;
use base qw(Exporter);
use base qw(DynaLoader);
package Math::GSL::Statisticsc;
bootstrap Math::GSL::Statistics;
package Math::GSL::Statistics;
@EXPORT = qw();

# ---------- BASE METHODS -------------

package Math::GSL::Statistics;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package Math::GSL::Statistics;

*gsl_stats_mean = *Math::GSL::Statisticsc::gsl_stats_mean;
*gsl_stats_variance = *Math::GSL::Statisticsc::gsl_stats_variance;
*gsl_stats_sd = *Math::GSL::Statisticsc::gsl_stats_sd;
*gsl_stats_variance_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_variance_with_fixed_mean;
*gsl_stats_sd_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_sd_with_fixed_mean;
*gsl_stats_tss = *Math::GSL::Statisticsc::gsl_stats_tss;
*gsl_stats_tss_m = *Math::GSL::Statisticsc::gsl_stats_tss_m;
*gsl_stats_absdev = *Math::GSL::Statisticsc::gsl_stats_absdev;
*gsl_stats_skew = *Math::GSL::Statisticsc::gsl_stats_skew;
*gsl_stats_kurtosis = *Math::GSL::Statisticsc::gsl_stats_kurtosis;
*gsl_stats_lag1_autocorrelation = *Math::GSL::Statisticsc::gsl_stats_lag1_autocorrelation;
*gsl_stats_covariance = *Math::GSL::Statisticsc::gsl_stats_covariance;
*gsl_stats_correlation = *Math::GSL::Statisticsc::gsl_stats_correlation;
*gsl_stats_variance_m = *Math::GSL::Statisticsc::gsl_stats_variance_m;
*gsl_stats_sd_m = *Math::GSL::Statisticsc::gsl_stats_sd_m;
*gsl_stats_absdev_m = *Math::GSL::Statisticsc::gsl_stats_absdev_m;
*gsl_stats_skew_m_sd = *Math::GSL::Statisticsc::gsl_stats_skew_m_sd;
*gsl_stats_kurtosis_m_sd = *Math::GSL::Statisticsc::gsl_stats_kurtosis_m_sd;
*gsl_stats_lag1_autocorrelation_m = *Math::GSL::Statisticsc::gsl_stats_lag1_autocorrelation_m;
*gsl_stats_covariance_m = *Math::GSL::Statisticsc::gsl_stats_covariance_m;
*gsl_stats_wmean = *Math::GSL::Statisticsc::gsl_stats_wmean;
*gsl_stats_wvariance = *Math::GSL::Statisticsc::gsl_stats_wvariance;
*gsl_stats_wsd = *Math::GSL::Statisticsc::gsl_stats_wsd;
*gsl_stats_wvariance_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_wvariance_with_fixed_mean;
*gsl_stats_wsd_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_wsd_with_fixed_mean;
*gsl_stats_wtss = *Math::GSL::Statisticsc::gsl_stats_wtss;
*gsl_stats_wtss_m = *Math::GSL::Statisticsc::gsl_stats_wtss_m;
*gsl_stats_wabsdev = *Math::GSL::Statisticsc::gsl_stats_wabsdev;
*gsl_stats_wskew = *Math::GSL::Statisticsc::gsl_stats_wskew;
*gsl_stats_wkurtosis = *Math::GSL::Statisticsc::gsl_stats_wkurtosis;
*gsl_stats_wvariance_m = *Math::GSL::Statisticsc::gsl_stats_wvariance_m;
*gsl_stats_wsd_m = *Math::GSL::Statisticsc::gsl_stats_wsd_m;
*gsl_stats_wabsdev_m = *Math::GSL::Statisticsc::gsl_stats_wabsdev_m;
*gsl_stats_wskew_m_sd = *Math::GSL::Statisticsc::gsl_stats_wskew_m_sd;
*gsl_stats_wkurtosis_m_sd = *Math::GSL::Statisticsc::gsl_stats_wkurtosis_m_sd;
*gsl_stats_pvariance = *Math::GSL::Statisticsc::gsl_stats_pvariance;
*gsl_stats_ttest = *Math::GSL::Statisticsc::gsl_stats_ttest;
*gsl_stats_max = *Math::GSL::Statisticsc::gsl_stats_max;
*gsl_stats_min = *Math::GSL::Statisticsc::gsl_stats_min;
*gsl_stats_minmax = *Math::GSL::Statisticsc::gsl_stats_minmax;
*gsl_stats_max_index = *Math::GSL::Statisticsc::gsl_stats_max_index;
*gsl_stats_min_index = *Math::GSL::Statisticsc::gsl_stats_min_index;
*gsl_stats_minmax_index = *Math::GSL::Statisticsc::gsl_stats_minmax_index;
*gsl_stats_median_from_sorted_data = *Math::GSL::Statisticsc::gsl_stats_median_from_sorted_data;
*gsl_stats_quantile_from_sorted_data = *Math::GSL::Statisticsc::gsl_stats_quantile_from_sorted_data;
*gsl_stats_int_mean = *Math::GSL::Statisticsc::gsl_stats_int_mean;
*gsl_stats_int_variance = *Math::GSL::Statisticsc::gsl_stats_int_variance;
*gsl_stats_int_sd = *Math::GSL::Statisticsc::gsl_stats_int_sd;
*gsl_stats_int_variance_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_int_variance_with_fixed_mean;
*gsl_stats_int_sd_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_int_sd_with_fixed_mean;
*gsl_stats_int_tss = *Math::GSL::Statisticsc::gsl_stats_int_tss;
*gsl_stats_int_tss_m = *Math::GSL::Statisticsc::gsl_stats_int_tss_m;
*gsl_stats_int_absdev = *Math::GSL::Statisticsc::gsl_stats_int_absdev;
*gsl_stats_int_skew = *Math::GSL::Statisticsc::gsl_stats_int_skew;
*gsl_stats_int_kurtosis = *Math::GSL::Statisticsc::gsl_stats_int_kurtosis;
*gsl_stats_int_lag1_autocorrelation = *Math::GSL::Statisticsc::gsl_stats_int_lag1_autocorrelation;
*gsl_stats_int_covariance = *Math::GSL::Statisticsc::gsl_stats_int_covariance;
*gsl_stats_int_correlation = *Math::GSL::Statisticsc::gsl_stats_int_correlation;
*gsl_stats_int_variance_m = *Math::GSL::Statisticsc::gsl_stats_int_variance_m;
*gsl_stats_int_sd_m = *Math::GSL::Statisticsc::gsl_stats_int_sd_m;
*gsl_stats_int_absdev_m = *Math::GSL::Statisticsc::gsl_stats_int_absdev_m;
*gsl_stats_int_skew_m_sd = *Math::GSL::Statisticsc::gsl_stats_int_skew_m_sd;
*gsl_stats_int_kurtosis_m_sd = *Math::GSL::Statisticsc::gsl_stats_int_kurtosis_m_sd;
*gsl_stats_int_lag1_autocorrelation_m = *Math::GSL::Statisticsc::gsl_stats_int_lag1_autocorrelation_m;
*gsl_stats_int_covariance_m = *Math::GSL::Statisticsc::gsl_stats_int_covariance_m;
*gsl_stats_int_pvariance = *Math::GSL::Statisticsc::gsl_stats_int_pvariance;
*gsl_stats_int_ttest = *Math::GSL::Statisticsc::gsl_stats_int_ttest;
*gsl_stats_int_max = *Math::GSL::Statisticsc::gsl_stats_int_max;
*gsl_stats_int_min = *Math::GSL::Statisticsc::gsl_stats_int_min;
*gsl_stats_int_minmax = *Math::GSL::Statisticsc::gsl_stats_int_minmax;
*gsl_stats_int_max_index = *Math::GSL::Statisticsc::gsl_stats_int_max_index;
*gsl_stats_int_min_index = *Math::GSL::Statisticsc::gsl_stats_int_min_index;
*gsl_stats_int_minmax_index = *Math::GSL::Statisticsc::gsl_stats_int_minmax_index;
*gsl_stats_int_median_from_sorted_data = *Math::GSL::Statisticsc::gsl_stats_int_median_from_sorted_data;
*gsl_stats_int_quantile_from_sorted_data = *Math::GSL::Statisticsc::gsl_stats_int_quantile_from_sorted_data;
*gsl_stats_char_mean = *Math::GSL::Statisticsc::gsl_stats_char_mean;
*gsl_stats_char_variance = *Math::GSL::Statisticsc::gsl_stats_char_variance;
*gsl_stats_char_sd = *Math::GSL::Statisticsc::gsl_stats_char_sd;
*gsl_stats_char_variance_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_char_variance_with_fixed_mean;
*gsl_stats_char_sd_with_fixed_mean = *Math::GSL::Statisticsc::gsl_stats_char_sd_with_fixed_mean;
*gsl_stats_char_tss = *Math::GSL::Statisticsc::gsl_stats_char_tss;
*gsl_stats_char_tss_m = *Math::GSL::Statisticsc::gsl_stats_char_tss_m;
*gsl_stats_char_absdev = *Math::GSL::Statisticsc::gsl_stats_char_absdev;
*gsl_stats_char_skew = *Math::GSL::Statisticsc::gsl_stats_char_skew;
*gsl_stats_char_kurtosis = *Math::GSL::Statisticsc::gsl_stats_char_kurtosis;
*gsl_stats_char_lag1_autocorrelation = *Math::GSL::Statisticsc::gsl_stats_char_lag1_autocorrelation;
*gsl_stats_char_covariance = *Math::GSL::Statisticsc::gsl_stats_char_covariance;
*gsl_stats_char_correlation = *Math::GSL::Statisticsc::gsl_stats_char_correlation;
*gsl_stats_char_variance_m = *Math::GSL::Statisticsc::gsl_stats_char_variance_m;
*gsl_stats_char_sd_m = *Math::GSL::Statisticsc::gsl_stats_char_sd_m;
*gsl_stats_char_absdev_m = *Math::GSL::Statisticsc::gsl_stats_char_absdev_m;
*gsl_stats_char_skew_m_sd = *Math::GSL::Statisticsc::gsl_stats_char_skew_m_sd;
*gsl_stats_char_kurtosis_m_sd = *Math::GSL::Statisticsc::gsl_stats_char_kurtosis_m_sd;
*gsl_stats_char_lag1_autocorrelation_m = *Math::GSL::Statisticsc::gsl_stats_char_lag1_autocorrelation_m;
*gsl_stats_char_covariance_m = *Math::GSL::Statisticsc::gsl_stats_char_covariance_m;
*gsl_stats_char_pvariance = *Math::GSL::Statisticsc::gsl_stats_char_pvariance;
*gsl_stats_char_ttest = *Math::GSL::Statisticsc::gsl_stats_char_ttest;
*gsl_stats_char_max = *Math::GSL::Statisticsc::gsl_stats_char_max;
*gsl_stats_char_min = *Math::GSL::Statisticsc::gsl_stats_char_min;
*gsl_stats_char_minmax = *Math::GSL::Statisticsc::gsl_stats_char_minmax;
*gsl_stats_char_max_index = *Math::GSL::Statisticsc::gsl_stats_char_max_index;
*gsl_stats_char_min_index = *Math::GSL::Statisticsc::gsl_stats_char_min_index;
*gsl_stats_char_minmax_index = *Math::GSL::Statisticsc::gsl_stats_char_minmax_index;
*gsl_stats_char_median_from_sorted_data = *Math::GSL::Statisticsc::gsl_stats_char_median_from_sorted_data;
*gsl_stats_char_quantile_from_sorted_data = *Math::GSL::Statisticsc::gsl_stats_char_quantile_from_sorted_data;

# ------- VARIABLE STUBS --------

package Math::GSL::Statistics;


@EXPORT_OK = qw/
               gsl_stats_mean 
               gsl_stats_variance 
               gsl_stats_sd 
               gsl_stats_variance_with_fixed_mean 
               gsl_stats_sd_with_fixed_mean 
               gsl_stats_tss 
               gsl_stats_tss_m 
               gsl_stats_absdev 
               gsl_stats_skew 
               gsl_stats_kurtosis 
               gsl_stats_lag1_autocorrelation 
               gsl_stats_covariance 
               gsl_stats_correlation 
               gsl_stats_variance_m 
               gsl_stats_sd_m 
               gsl_stats_absdev_m 
               gsl_stats_skew_m_sd 
               gsl_stats_kurtosis_m_sd 
               gsl_stats_lag1_autocorrelation_m 
               gsl_stats_covariance_m 
               gsl_stats_wmean 
               gsl_stats_wvariance 
               gsl_stats_wsd 
               gsl_stats_wvariance_with_fixed_mean 
               gsl_stats_wsd_with_fixed_mean 
               gsl_stats_wtss 
               gsl_stats_wtss_m 
               gsl_stats_wabsdev 
               gsl_stats_wskew 
               gsl_stats_wkurtosis 
               gsl_stats_wvariance_m 
               gsl_stats_wsd_m 
               gsl_stats_wabsdev_m 
               gsl_stats_wskew_m_sd 
               gsl_stats_wkurtosis_m_sd 
               gsl_stats_pvariance 
               gsl_stats_ttest 
               gsl_stats_max 
               gsl_stats_min 
               gsl_stats_minmax 
               gsl_stats_max_index 
               gsl_stats_min_index 
               gsl_stats_minmax_index 
               gsl_stats_median_from_sorted_data 
               gsl_stats_quantile_from_sorted_data 
               /;
our @EXPORT_int = qw/
               gsl_stats_int_mean 
               gsl_stats_int_variance 
               gsl_stats_int_sd 
               gsl_stats_int_variance_with_fixed_mean 
               gsl_stats_int_sd_with_fixed_mean 
               gsl_stats_int_tss 
               gsl_stats_int_tss_m 
               gsl_stats_int_absdev 
               gsl_stats_int_skew 
               gsl_stats_int_kurtosis 
               gsl_stats_int_lag1_autocorrelation 
               gsl_stats_int_covariance 
               gsl_stats_int_correlation 
               gsl_stats_int_variance_m 
               gsl_stats_int_sd_m 
               gsl_stats_int_absdev_m 
               gsl_stats_int_skew_m_sd 
               gsl_stats_int_kurtosis_m_sd 
               gsl_stats_int_lag1_autocorrelation_m 
               gsl_stats_int_covariance_m 
               gsl_stats_int_pvariance 
               gsl_stats_int_ttest 
               gsl_stats_int_max 
               gsl_stats_int_min 
               gsl_stats_int_minmax 
               gsl_stats_int_max_index 
               gsl_stats_int_min_index 
               gsl_stats_int_minmax_index 
               gsl_stats_int_median_from_sorted_data 
               gsl_stats_int_quantile_from_sorted_data 
               /;
our @EXPORT_char = qw/
               gsl_stats_char_mean 
               gsl_stats_char_variance 
               gsl_stats_char_sd 
               gsl_stats_char_variance_with_fixed_mean 
               gsl_stats_char_sd_with_fixed_mean 
               gsl_stats_char_tss 
               gsl_stats_char_tss_m 
               gsl_stats_char_absdev 
               gsl_stats_char_skew 
               gsl_stats_char_kurtosis 
               gsl_stats_char_lag1_autocorrelation 
               gsl_stats_char_covariance 
               gsl_stats_char_correlation 
               gsl_stats_char_variance_m 
               gsl_stats_char_sd_m 
               gsl_stats_char_absdev_m 
               gsl_stats_char_skew_m_sd 
               gsl_stats_char_kurtosis_m_sd 
               gsl_stats_char_lag1_autocorrelation_m 
               gsl_stats_char_covariance_m 
               gsl_stats_char_pvariance 
               gsl_stats_char_ttest 
               gsl_stats_char_max 
               gsl_stats_char_min 
               gsl_stats_char_minmax 
               gsl_stats_char_max_index 
               gsl_stats_char_min_index 
               gsl_stats_char_minmax_index 
               gsl_stats_char_median_from_sorted_data 
               gsl_stats_char_quantile_from_sorted_data 
             /;
push @EXPORT_OK, @EXPORT_int, @EXPORT_char;
%EXPORT_TAGS = ( 
                all => \@EXPORT_OK,
                int => \@EXPORT_int,
                char => \@EXPORT_char
               );
1;
